Documentation
¶
Overview ¶
Package testutils contains candidates to be moved to go-common/testutils
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Eventually ¶
Types ¶
type PathResponse ¶ added in v0.7.0
type Responses ¶ added in v0.7.0
type Responses map[string]PathResponse
type TestServer ¶
type TestServer struct {
Responses Responses
// contains filtered or unexported fields
}
func (*TestServer) Calls ¶
func (t *TestServer) Calls() map[string]int
Calls returns how many requests were accepted for each path.
func (*TestServer) ServeHTTP ¶
func (t *TestServer) ServeHTTP(w http.ResponseWriter, r *http.Request)
func (*TestServer) TotalCalls ¶
func (t *TestServer) TotalCalls() int
TotalCalls returns how many requests were accepted for all paths.
Click to show internal directories.
Click to hide internal directories.